"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .putintegrationsintegrationidcustomfieldscustomfieldidrequestbody import (
    PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody,
    PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestTypedDict(TypedDict):
    integration_id: str
    r"""The unique ID of the integration where the custom field mapping should be updated"""
    custom_field_id: str
    r"""The unique ID of the custom field that should be updated"""
    body: PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBodyTypedDict
    r"""PUT /integrations/:integration_id/custom-fields/:custom_field_id Request body"""


class PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequest(BaseModel):
    integration_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The unique ID of the integration where the custom field mapping should be updated"""

    custom_field_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The unique ID of the custom field that should be updated"""

    body: Annotated[
        PutIntegrationsIntegrationIDCustomFieldsCustomFieldIDRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""PUT /integrations/:integration_id/custom-fields/:custom_field_id Request body"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class AssetsTypedDict(TypedDict):
    logo_url: str
    icon_url: str
    icon_black_url: str


class Assets(BaseModel):
    logo_url: str

    icon_url: str

    icon_black_url: str


GetToolsCategoryPositiveResponseReadModelCoverageStatus = Literal[
    "SUPPORTED",
    "UNSUPPORTED",
    "NOT_IMPLEMENTED",
    "UNKNOWN",
]
r"""The status of a datapoint of an integrated tool:

- `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
- `UNSUPPORTED`: the tool does not support the datapoint.
- `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
- `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
"""


GetToolsCategoryPositiveResponseFieldCoverageStatus = Literal[
    "SUPPORTED",
    "UNSUPPORTED",
    "NOT_IMPLEMENTED",
    "UNKNOWN",
]
r"""The status of a datapoint of an integrated tool:

- `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
- `UNSUPPORTED`: the tool does not support the datapoint.
- `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
- `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
"""


class GetToolsCategoryPositiveResponseFieldTypedDict(TypedDict):
    id: str
    r"""Key of the field in the model (e.g. first_name)."""
    coverage_status: GetToolsCategoryPositiveResponseFieldCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """


class GetToolsCategoryPositiveResponseField(BaseModel):
    id: str
    r"""Key of the field in the model (e.g. first_name)."""

    coverage_status: GetToolsCategoryPositiveResponseFieldCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """


class GetToolsCategoryPositiveResponseReadModelTypedDict(TypedDict):
    r"""List of models we can read for this tool."""

    id: str
    r"""ID of the model (e.g. hris_employees)."""
    label: str
    r"""Label of the model (e.g. Employees)."""
    coverage_status: GetToolsCategoryPositiveResponseReadModelCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """
    fields: List[GetToolsCategoryPositiveResponseFieldTypedDict]


class GetToolsCategoryPositiveResponseReadModel(BaseModel):
    r"""List of models we can read for this tool."""

    id: str
    r"""ID of the model (e.g. hris_employees)."""

    label: str
    r"""Label of the model (e.g. Employees)."""

    coverage_status: GetToolsCategoryPositiveResponseReadModelCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """

    fields: List[GetToolsCategoryPositiveResponseField]


WriteActionCoverageStatus = Literal[
    "SUPPORTED",
    "UNSUPPORTED",
    "NOT_IMPLEMENTED",
    "UNKNOWN",
]
r"""The status of a datapoint of an integrated tool:

- `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
- `UNSUPPORTED`: the tool does not support the datapoint.
- `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
- `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
"""


class WriteActionTypedDict(TypedDict):
    r"""List of supported write actions for this tool."""

    id: str
    label: str
    coverage_status: WriteActionCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """


class WriteAction(BaseModel):
    r"""List of supported write actions for this tool."""

    id: str

    label: str

    coverage_status: WriteActionCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """


FeatureCoverageStatus = Literal[
    "SUPPORTED",
    "UNSUPPORTED",
    "NOT_IMPLEMENTED",
    "UNKNOWN",
]
r"""The status of a datapoint of an integrated tool:

- `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
- `UNSUPPORTED`: the tool does not support the datapoint.
- `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
- `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
"""


class FeatureTypedDict(TypedDict):
    id: str
    label: str
    coverage_status: FeatureCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """


class Feature(BaseModel):
    id: str

    label: str

    coverage_status: FeatureCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """


class CoverageTypedDict(TypedDict):
    r"""This describes the supported models and actions of this tool."""

    read_models: List[GetToolsCategoryPositiveResponseReadModelTypedDict]
    write_actions: List[WriteActionTypedDict]
    features: List[FeatureTypedDict]


class Coverage(BaseModel):
    r"""This describes the supported models and actions of this tool."""

    read_models: List[GetToolsCategoryPositiveResponseReadModel]

    write_actions: List[WriteAction]

    features: List[Feature]


class GetToolsCategoryPositiveResponseToolTypedDict(TypedDict):
    id: str
    label: str
    internal_label: Nullable[str]
    r"""Internal label that can help you debug specific variants of the integration. Only show the `label` to your users."""
    assets: AssetsTypedDict
    paid_api_details_markdown: Nullable[str]
    r"""Markdown formatted text that describes details about the paid API. `null` if the tool is not paid."""
    fast_track_details_markdown: Nullable[str]
    r"""Markdown formatted text that describes details about the fast track process. `null` if the fast track process is not available."""
    partner_only_details_markdown: Nullable[str]
    r"""Markdown formatted text that describes partnership requirements. `null` if the tool does not require a partnership."""
    connection_guide_url: Nullable[str]
    r"""URL to the connection guide for this tool. `null` if no connection guide is available."""
    coverage: CoverageTypedDict
    r"""This describes the supported models and actions of this tool."""


class GetToolsCategoryPositiveResponseTool(BaseModel):
    id: str

    label: str

    internal_label: Nullable[str]
    r"""Internal label that can help you debug specific variants of the integration. Only show the `label` to your users."""

    assets: Assets

    paid_api_details_markdown: Nullable[str]
    r"""Markdown formatted text that describes details about the paid API. `null` if the tool is not paid."""

    fast_track_details_markdown: Nullable[str]
    r"""Markdown formatted text that describes details about the fast track process. `null` if the fast track process is not available."""

    partner_only_details_markdown: Nullable[str]
    r"""Markdown formatted text that describes partnership requirements. `null` if the tool does not require a partnership."""

    connection_guide_url: Nullable[str]
    r"""URL to the connection guide for this tool. `null` if no connection guide is available."""

    coverage: Coverage
    r"""This describes the supported models and actions of this tool."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "internal_label",
            "paid_api_details_markdown",
            "fast_track_details_markdown",
            "partner_only_details_markdown",
            "connection_guide_url",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetToolsCategoryPositiveResponseDataTypedDict(TypedDict):
    tools: List[GetToolsCategoryPositiveResponseToolTypedDict]


class GetToolsCategoryPositiveResponseData(BaseModel):
    tools: List[GetToolsCategoryPositiveResponseTool]


class GetToolsCategoryPositiveResponseTypedDict(TypedDict):
    data: GetToolsCategoryPositiveResponseDataTypedDict
    status: Literal["success"]


class GetToolsCategoryPositiveResponse(BaseModel):
    data: GetToolsCategoryPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


GetHrisTimeOffBalancesPositiveResponseBalanceUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The time-unit of the balance."""


GetHrisTimeOffBalancesPositiveResponseUsedUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The time-unit of the used time."""


GetHrisTimeOffBalancesPositiveResponseUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The time-unit of the absence."""


class GetHrisTimeOffBalancesPositiveResponseTypeTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The absence’s name."""
    unit: Nullable[GetHrisTimeOffBalancesPositiveResponseUnit]
    r"""The time-unit of the absence."""
    half_days_supported: Nullable[bool]
    r"""Whether the integration supports half-day absences (represented through `start_half_day` and `end_half_day`) for this absence type."""
    exact_times_supported: Nullable[bool]
    r"""`true` if the system supports exact times (absences with a `start_time` and an `end_time`) for this absence, `false` if not."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """


class GetHrisTimeOffBalancesPositiveResponseType(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The absence’s name."""

    unit: Nullable[GetHrisTimeOffBalancesPositiveResponseUnit]
    r"""The time-unit of the absence."""

    half_days_supported: Nullable[bool]
    r"""Whether the integration supports half-day absences (represented through `start_half_day` and `end_half_day`) for this absence type."""

    exact_times_supported: Nullable[bool]
    r"""`true` if the system supports exact times (absences with a `start_time` and an `end_time`) for this absence, `false` if not."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "name",
            "unit",
            "half_days_supported",
            "exact_times_supported",
            "remote_deleted_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisTimeOffBalancesPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    employee_id: str
    r"""The Kombo ID of the employee to which the balance belongs to. The ID can be used to retrieve the employee from the `get employees` endpoint."""
    type_id: str
    balance: Nullable[float]
    r"""The amount of time available to the employee."""
    balance_unit: Nullable[GetHrisTimeOffBalancesPositiveResponseBalanceUnit]
    r"""The time-unit of the balance."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    used: Nullable[float]
    r"""The amount of time used by the employee."""
    used_unit: Nullable[GetHrisTimeOffBalancesPositiveResponseUsedUnit]
    r"""The time-unit of the used time."""
    type: GetHrisTimeOffBalancesPositiveResponseTypeTypedDict


class GetHrisTimeOffBalancesPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    employee_id: str
    r"""The Kombo ID of the employee to which the balance belongs to. The ID can be used to retrieve the employee from the `get employees` endpoint."""

    type_id: str

    balance: Nullable[float]
    r"""The amount of time available to the employee."""

    balance_unit: Nullable[GetHrisTimeOffBalancesPositiveResponseBalanceUnit]
    r"""The time-unit of the balance."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    used: Nullable[float]
    r"""The amount of time used by the employee."""

    used_unit: Nullable[GetHrisTimeOffBalancesPositiveResponseUsedUnit]
    r"""The time-unit of the used time."""

    type: GetHrisTimeOffBalancesPositiveResponseType

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "remote_id",
            "balance",
            "balance_unit",
            "remote_deleted_at",
            "used",
            "used_unit",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisTimeOffBalancesPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetHrisTimeOffBalancesPositiveResponseResultTypedDict]


class GetHrisTimeOffBalancesPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetHrisTimeOffBalancesPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisTimeOffBalancesPositiveResponseTypedDict(TypedDict):
    data: GetHrisTimeOffBalancesPositiveResponseDataTypedDict
    status: Literal["success"]


class GetHrisTimeOffBalancesPositiveResponse(BaseModel):
    data: GetHrisTimeOffBalancesPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


Method = Literal[
    "GET",
    "POST",
    "DELETE",
    "PUT",
    "PATCH",
]
r"""The HTTP method (e.g., `GET`) of the request."""


class ValueTypedDict(TypedDict):
    name: str
    r"""File name of the file you want to upload. We recommend providing something human-readable with a valid file extension (like `Resume.pdf`), as this might be shown in your customer's system."""
    content_type: NotRequired[str]
    r"""Content/MIME type of the file (e.g., `application/pdf`).

    If you provide `data`, this is required. If you provide `data_url`, this is optional and we'll attempt to use the `Content-Type` header of the response.

    **Note:** Please validate that the content type you provide is actually meaningful (and not something generic like [`application/octet-stream`](https://developer.mozilla.org/en-US/docs/Web/HTTP/Guides/MIME_types#applicationoctet-stream)). Especially when using object storage (like AWS S3), it's easy to accidentally discard the content types of user-provided files, so make sure to explicitly persist them when processing uploads from your users (see guides for [AWS](https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingMetadata.html#SysMetadata), [Google Cloud](https://cloud.google.com/storage/docs/metadata#content-type), and [Azure](https://learn.microsoft.com/en-us/rest/api/storageservices/put-blob#request-headers-all-blob-types)).
    """
    data_url: NotRequired[str]
    r"""URL to the file you want to upload that can be accessed without authentication headers. We will download the content immediately when receiving the request, so the URL can be short-lived.

    If you're using an object storage provider (like AWS S3), we strongly recommend providing a signed URL for secure access (see guides for [AWS](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ShareObjectPreSignedURL.html), [Google Cloud](https://cloud.google.com/storage/docs/access-control/signed-urls), and [Azure](https://learn.microsoft.com/en-us/azure/storage/common/storage-sas-overview)).

    **Note:** You must provide either this or `data_url`. We recommend `data_url` over `data` for most cases.
    """
    data: NotRequired[str]
    r"""Base64-encoded contents of the file you want to upload.

    **Note:** You must provide either this or `data_url`. We recommend `data_url` over `data` for most cases.
    """


class Value(BaseModel):
    name: str
    r"""File name of the file you want to upload. We recommend providing something human-readable with a valid file extension (like `Resume.pdf`), as this might be shown in your customer's system."""

    content_type: Optional[str] = None
    r"""Content/MIME type of the file (e.g., `application/pdf`).

    If you provide `data`, this is required. If you provide `data_url`, this is optional and we'll attempt to use the `Content-Type` header of the response.

    **Note:** Please validate that the content type you provide is actually meaningful (and not something generic like [`application/octet-stream`](https://developer.mozilla.org/en-US/docs/Web/HTTP/Guides/MIME_types#applicationoctet-stream)). Especially when using object storage (like AWS S3), it's easy to accidentally discard the content types of user-provided files, so make sure to explicitly persist them when processing uploads from your users (see guides for [AWS](https://docs.aws.amazon.com/AmazonS3/latest/userguide/UsingMetadata.html#SysMetadata), [Google Cloud](https://cloud.google.com/storage/docs/metadata#content-type), and [Azure](https://learn.microsoft.com/en-us/rest/api/storageservices/put-blob#request-headers-all-blob-types)).
    """

    data_url: Optional[str] = None
    r"""URL to the file you want to upload that can be accessed without authentication headers. We will download the content immediately when receiving the request, so the URL can be short-lived.

    If you're using an object storage provider (like AWS S3), we strongly recommend providing a signed URL for secure access (see guides for [AWS](https://docs.aws.amazon.com/AmazonS3/latest/userguide/ShareObjectPreSignedURL.html), [Google Cloud](https://cloud.google.com/storage/docs/access-control/signed-urls), and [Azure](https://learn.microsoft.com/en-us/azure/storage/common/storage-sas-overview)).

    **Note:** You must provide either this or `data_url`. We recommend `data_url` over `data` for most cases.
    """

    data: Optional[str] = None
    r"""Base64-encoded contents of the file you want to upload.

    **Note:** You must provide either this or `data_url`. We recommend `data_url` over `data` for most cases.
    """


ValueUnionTypedDict = TypeAliasType("ValueUnionTypedDict", Union[ValueTypedDict, str])


ValueUnion = TypeAliasType("ValueUnion", Union[Value, str])


class MultipartFormDatumTypedDict(TypedDict):
    r"""The data to submit as part of the request body if the request's `Content-Type` is `multipart/form-data`."""

    name: str
    r"""The key of the form data"""
    value: ValueUnionTypedDict


class MultipartFormDatum(BaseModel):
    r"""The data to submit as part of the request body if the request's `Content-Type` is `multipart/form-data`."""

    name: str
    r"""The key of the form data"""

    value: ValueUnion


class PostPassthroughToolAPIRequestBodyTypedDict(TypedDict):
    method: Method
    r"""The HTTP method (e.g., `GET`) of the request."""
    path: str
    r"""The path of the endpoint you want to call. We automatically prepend the base URL of the API (all base URLs are documented in the endpoint description)."""
    headers: NotRequired[Dict[str, str]]
    r"""The headers to send with the request. Note that we automatically supply any authentication-related headers."""
    params: NotRequired[Dict[str, str]]
    r"""The query parameters to send in addition to the ones in the `path`."""
    data: NotRequired[Any]
    r"""The data to submit as part of the request body. This can either be an array or object (in which case we will forward it as JSON) or a string (in which case we will forward it raw)."""
    response_as_base64: NotRequired[bool]
    r"""If set to `true`, the response will be returned as a base64-encoded string. This is useful for binary data (e.g., PDFs)."""
    multipart_form_data: NotRequired[List[MultipartFormDatumTypedDict]]
    api_options: NotRequired[Dict[str, str]]
    r"""Custom options interpreted by the passthrough API adapter you've selected. These options are not documented right now as they're only for very advanced use cases."""


class PostPassthroughToolAPIRequestBody(BaseModel):
    method: Method
    r"""The HTTP method (e.g., `GET`) of the request."""

    path: str
    r"""The path of the endpoint you want to call. We automatically prepend the base URL of the API (all base URLs are documented in the endpoint description)."""

    headers: Optional[Dict[str, str]] = None
    r"""The headers to send with the request. Note that we automatically supply any authentication-related headers."""

    params: Optional[Dict[str, str]] = None
    r"""The query parameters to send in addition to the ones in the `path`."""

    data: Optional[Any] = None
    r"""The data to submit as part of the request body. This can either be an array or object (in which case we will forward it as JSON) or a string (in which case we will forward it raw)."""

    response_as_base64: Optional[bool] = None
    r"""If set to `true`, the response will be returned as a base64-encoded string. This is useful for binary data (e.g., PDFs)."""

    multipart_form_data: Optional[List[MultipartFormDatum]] = None

    api_options: Optional[Dict[str, str]] = None
    r"""Custom options interpreted by the passthrough API adapter you've selected. These options are not documented right now as they're only for very advanced use cases."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


GetToolsCategoryParameterCategory = Literal[
    "hris",
    "ats",
    "assessment",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, HeaderMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetAssessmentPackagesGlobalsTypedDict(TypedDict):
    integration_id: NotRequired[str]
    r"""ID of the integration you want to interact with."""


class GetAssessmentPackagesGlobals(BaseModel):
    integration_id: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Integration-Id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""ID of the integration you want to interact with."""


class GetAssessmentPackagesRequestTypedDict(TypedDict):
    pass


class GetAssessmentPackagesRequest(BaseModel):
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, NotRequired, TypedDict


class GetAssessmentOrdersOpenPositiveResponseCandidateTypedDict(TypedDict):
    r"""Information about the candidate taking the assessment."""

    email: str
    r"""The candidate's email address."""
    first_name: NotRequired[Nullable[str]]
    r"""The candidate's first name."""
    last_name: NotRequired[Nullable[str]]
    r"""The candidate's last name."""
    phone: NotRequired[Nullable[str]]
    r"""The candidate's phone number."""
    remote_id: NotRequired[Nullable[str]]
    r"""The candidate's identifier in the integrated system."""


class GetAssessmentOrdersOpenPositiveResponseCandidate(BaseModel):
    r"""Information about the candidate taking the assessment."""

    email: str
    r"""The candidate's email address."""

    first_name: OptionalNullable[str] = UNSET
    r"""The candidate's first name."""

    last_name: OptionalNullable[str] = UNSET
    r"""The candidate's last name."""

    phone: OptionalNullable[str] = UNSET
    r"""The candidate's phone number."""

    remote_id: OptionalNullable[str] = UNSET
    r"""The candidate's identifier in the integrated system."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["first_name", "last_name", "phone", "remote_id"]
        nullable_fields = ["first_name", "last_name", "phone", "remote_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAssessmentOrdersOpenPositiveResponseApplicationTypedDict(TypedDict):
    r"""Information about the job application."""

    remote_id: NotRequired[Nullable[str]]
    r"""The application's identifier in the integrated system."""


class GetAssessmentOrdersOpenPositiveResponseApplication(BaseModel):
    r"""Information about the job application."""

    remote_id: OptionalNullable[str] = UNSET
    r"""The application's identifier in the integrated system."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["remote_id"]
        nullable_fields = ["remote_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAssessmentOrdersOpenPositiveResponseLocationTypedDict(TypedDict):
    r"""The job location information."""

    city: NotRequired[Nullable[str]]
    country: NotRequired[Nullable[str]]
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""
    raw: NotRequired[Nullable[str]]
    r"""If we have address data, this is filled with the raw address string."""
    state: NotRequired[Nullable[str]]
    street_1: NotRequired[Nullable[str]]
    r"""If we can parse the address data, this field contains the first part of the street information."""
    street_2: NotRequired[Nullable[str]]
    zip_code: NotRequired[Nullable[str]]


class GetAssessmentOrdersOpenPositiveResponseLocation(BaseModel):
    r"""The job location information."""

    city: OptionalNullable[str] = UNSET

    country: OptionalNullable[str] = UNSET
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""

    raw: OptionalNullable[str] = UNSET
    r"""If we have address data, this is filled with the raw address string."""

    state: OptionalNullable[str] = UNSET

    street_1: OptionalNullable[str] = UNSET
    r"""If we can parse the address data, this field contains the first part of the street information."""

    street_2: OptionalNullable[str] = UNSET

    zip_code: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "city",
            "country",
            "raw",
            "state",
            "street_1",
            "street_2",
            "zip_code",
        ]
        nullable_fields = [
            "city",
            "country",
            "raw",
            "state",
            "street_1",
            "street_2",
            "zip_code",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


GetAssessmentOrdersOpenPositiveResponseHiringTeamRole = Literal[
    "RECRUITER",
    "HIRING_MANAGER",
]


class GetAssessmentOrdersOpenPositiveResponseHiringTeamTypedDict(TypedDict):
    r"""A member of the hiring team."""

    remote_id: str
    r"""The team member's identifier in the integrated system."""
    email: Nullable[str]
    r"""The team member's email address."""
    first_name: Nullable[str]
    r"""The team member's first name."""
    last_name: Nullable[str]
    r"""The team member's last name."""
    hiring_team_roles: List[GetAssessmentOrdersOpenPositiveResponseHiringTeamRole]
    r"""Array of the roles of the user for this specific job. Currently only `RECRUITER` and `HIRING_MANAGER` are mapped into our unified schema."""


class GetAssessmentOrdersOpenPositiveResponseHiringTeam(BaseModel):
    r"""A member of the hiring team."""

    remote_id: str
    r"""The team member's identifier in the integrated system."""

    email: Nullable[str]
    r"""The team member's email address."""

    first_name: Nullable[str]
    r"""The team member's first name."""

    last_name: Nullable[str]
    r"""The team member's last name."""

    hiring_team_roles: List[GetAssessmentOrdersOpenPositiveResponseHiringTeamRole]
    r"""Array of the roles of the user for this specific job. Currently only `RECRUITER` and `HIRING_MANAGER` are mapped into our unified schema."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["email", "first_name", "last_name"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAssessmentOrdersOpenPositiveResponseJobTypedDict(TypedDict):
    r"""Information about the job posting."""

    hiring_team: List[GetAssessmentOrdersOpenPositiveResponseHiringTeamTypedDict]
    r"""The hiring team allows you to sync users into your system who can access the job and its applications."""
    remote_id: NotRequired[Nullable[str]]
    r"""The job's identifier in the integrated system."""
    name: NotRequired[Nullable[str]]
    r"""The job title."""
    location: NotRequired[
        Nullable[GetAssessmentOrdersOpenPositiveResponseLocationTypedDict]
    ]
    r"""The job location information."""


class GetAssessmentOrdersOpenPositiveResponseJob(BaseModel):
    r"""Information about the job posting."""

    hiring_team: List[GetAssessmentOrdersOpenPositiveResponseHiringTeam]
    r"""The hiring team allows you to sync users into your system who can access the job and its applications."""

    remote_id: OptionalNullable[str] = UNSET
    r"""The job's identifier in the integrated system."""

    name: OptionalNullable[str] = UNSET
    r"""The job title."""

    location: OptionalNullable[GetAssessmentOrdersOpenPositiveResponseLocation] = UNSET
    r"""The job location information."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["remote_id", "name", "location"]
        nullable_fields = ["remote_id", "name", "location"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAssessmentOrdersOpenPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The unique identifier of the assessment order."""
    package_id: str
    r"""The identifier of the assessment package."""
    candidate: GetAssessmentOrdersOpenPositiveResponseCandidateTypedDict
    r"""Information about the candidate taking the assessment."""
    application: GetAssessmentOrdersOpenPositiveResponseApplicationTypedDict
    r"""Information about the job application."""
    job: GetAssessmentOrdersOpenPositiveResponseJobTypedDict
    r"""Information about the job posting."""


class GetAssessmentOrdersOpenPositiveResponseResult(BaseModel):
    id: str
    r"""The unique identifier of the assessment order."""

    package_id: str
    r"""The identifier of the assessment package."""

    candidate: GetAssessmentOrdersOpenPositiveResponseCandidate
    r"""Information about the candidate taking the assessment."""

    application: GetAssessmentOrdersOpenPositiveResponseApplication
    r"""Information about the job application."""

    job: GetAssessmentOrdersOpenPositiveResponseJob
    r"""Information about the job posting."""


class GetAssessmentOrdersOpenPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    results: List[GetAssessmentOrdersOpenPositiveResponseResultTypedDict]


class GetAssessmentOrdersOpenPositiveResponseData(BaseModel):
    next: Nullable[str]

    results: List[GetAssessmentOrdersOpenPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAssessmentOrdersOpenPositiveResponseTypedDict(TypedDict):
    data: GetAssessmentOrdersOpenPositiveResponseDataTypedDict
    status: Literal["success"]


class GetAssessmentOrdersOpenPositiveResponse(BaseModel):
    data: GetAssessmentOrdersOpenPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .gethristimeoffbalancespositiveresponse import (
    GetHrisTimeOffBalancesPositiveResponse,
    GetHrisTimeOffBalancesPositiveResponseTypedDict,
)
from datetime import datetime
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, HeaderMetadata, QueryParamMetadata
import pydantic
from typing import Awaitable, Callable, List, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class GetHrisTimeOffBalancesGlobalsTypedDict(TypedDict):
    integration_id: NotRequired[str]
    r"""ID of the integration you want to interact with."""


class GetHrisTimeOffBalancesGlobals(BaseModel):
    integration_id: Annotated[
        Optional[str],
        pydantic.Field(alias="X-Integration-Id"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""ID of the integration you want to interact with."""


class GetHrisTimeOffBalancesRequestTypedDict(TypedDict):
    cursor: NotRequired[str]
    r"""An optional cursor string used for pagination. This can be retrieved from the `next` property of the previous page response."""
    page_size: NotRequired[int]
    r"""The number of results to return per page. Maximum is 250."""
    updated_after: NotRequired[datetime]
    r"""Filter the entries based on the modification date in format `YYYY-MM-DDTHH:mm:ss.sssZ`. Returns records where either the record itself **OR** its nested data has been updated since this timestamp, even if the record's own `changed_at` field remains unchanged.

    If you want to track entry deletion, also set the `include_deleted=true` query parameter, because otherwise, deleted entries will be hidden.

    For more details, see [Understanding changed_at vs updated_after Behavior](https://docs.kombo.dev/ats/getting-started/fetching-data#understanding-changed_at-vs-updated_after-behavior).
    """
    include_deleted: NotRequired[bool]
    r"""By default, deleted entries are not returned. Use the `include_deleted` query param to include deleted entries too."""
    ids: NotRequired[List[str]]
    r"""Filter by a comma-separated list of IDs such as `222k7eCGyUdgt2JWZDNnkDs3,B5DVmypWENfU6eMe6gYDyJG3`."""
    remote_ids: NotRequired[List[str]]
    r"""Filter by a comma-separated list of remote IDs."""
    employee_id: NotRequired[str]
    r"""Filter by a specific employee using their ID."""


class GetHrisTimeOffBalancesRequest(BaseModel):
    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""An optional cursor string used for pagination. This can be retrieved from the `next` property of the previous page response."""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""The number of results to return per page. Maximum is 250."""

    updated_after: Annotated[
        Optional[datetime],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter the entries based on the modification date in format `YYYY-MM-DDTHH:mm:ss.sssZ`. Returns records where either the record itself **OR** its nested data has been updated since this timestamp, even if the record's own `changed_at` field remains unchanged.

    If you want to track entry deletion, also set the `include_deleted=true` query parameter, because otherwise, deleted entries will be hidden.

    For more details, see [Understanding changed_at vs updated_after Behavior](https://docs.kombo.dev/ats/getting-started/fetching-data#understanding-changed_at-vs-updated_after-behavior).
    """

    include_deleted: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = False
    r"""By default, deleted entries are not returned. Use the `include_deleted` query param to include deleted entries too."""

    ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of IDs such as `222k7eCGyUdgt2JWZDNnkDs3,B5DVmypWENfU6eMe6gYDyJG3`."""

    remote_ids: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Filter by a comma-separated list of remote IDs."""

    employee_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter by a specific employee using their ID."""


class GetHrisTimeOffBalancesResponseTypedDict(TypedDict):
    result: GetHrisTimeOffBalancesPositiveResponseTypedDict


class GetHrisTimeOffBalancesResponse(BaseModel):
    next: Union[
        Callable[[], Optional[GetHrisTimeOffBalancesResponse]],
        Callable[[], Awaitable[Optional[GetHrisTimeOffBalancesResponse]]],
    ]

    result: GetHrisTimeOffBalancesPositiveResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from kombo.errors import SDKError
from kombo.models import kombohriserror as models_kombohriserror
from kombo.types import BaseModel
from typing import Optional


class KomboHrisErrorData(BaseModel):
    status: models_kombohriserror.KomboHrisErrorStatus

    error: models_kombohriserror.KomboHrisErrorError
    r"""Error details with structured code for programmatic handling."""


@dataclass(unsafe_hash=True)
class KomboHrisError(SDKError):
    r"""The standard error response with the error codes for the HRIS use case."""

    data: KomboHrisErrorData = field(hash=False)

    def __init__(
        self,
        data: KomboHrisErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        fallback = body or raw_response.text
        message = str(data.error.message) or fallback
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Literal
from typing_extensions import Annotated, TypedDict


class DeleteIntegrationsIntegrationIDPositiveResponseDataTypedDict(TypedDict):
    pass


class DeleteIntegrationsIntegrationIDPositiveResponseData(BaseModel):
    pass


class DeleteIntegrationsIntegrationIDPositiveResponseTypedDict(TypedDict):
    data: DeleteIntegrationsIntegrationIDPositiveResponseDataTypedDict
    status: Literal["success"]


class DeleteIntegrationsIntegrationIDPositiveResponse(BaseModel):
    data: DeleteIntegrationsIntegrationIDPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


PostHrisAbsencesRequestBodyStatus = Literal[
    "REQUESTED",
    "APPROVED",
]
r"""The state that the absence should be created in. Some tools may approve absences automatically if they were created for an absence type that does not require approval."""


PostHrisAbsencesRequestBodyUnit = Literal[
    "HOURS",
    "DAYS",
]
r"""The time unit of the `amount` value. Specifying this also requires specifying `amount`."""


class PostHrisAbsencesRequestBodyAdpworkforcenowTypedDict(TypedDict):
    r"""Fields specific to ADP Workforce Now."""

    employment_id: NotRequired[str]
    r"""[Required] The employment ID of the employee that the absence will be added to."""
    paid_leave: NotRequired[bool]
    r"""Whether the absence is paid or not."""


class PostHrisAbsencesRequestBodyAdpworkforcenow(BaseModel):
    r"""Fields specific to ADP Workforce Now."""

    employment_id: Optional[str] = None
    r"""[Required] The employment ID of the employee that the absence will be added to."""

    paid_leave: Optional[bool] = None
    r"""Whether the absence is paid or not."""


class PostHrisAbsencesRequestBodyRemoteFieldsTypedDict(TypedDict):
    r"""Additional fields that we will pass through to specific HRIS systems."""

    adpworkforcenow: NotRequired[PostHrisAbsencesRequestBodyAdpworkforcenowTypedDict]
    r"""Fields specific to ADP Workforce Now."""


class PostHrisAbsencesRequestBodyRemoteFields(BaseModel):
    r"""Additional fields that we will pass through to specific HRIS systems."""

    adpworkforcenow: Optional[PostHrisAbsencesRequestBodyAdpworkforcenow] = None
    r"""Fields specific to ADP Workforce Now."""


class PostHrisAbsencesRequestBodyTypedDict(TypedDict):
    employee_id: str
    r"""The ID of the employee in Kombo or their ID in the remote system by prefixing it with `remote:` (e.g., `remote:12312`)"""
    absence_type_id: str
    r"""The ID of the absence type in Kombo (not its `remote_id`)."""
    start_date: datetime
    r"""The date that the absence starts. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    end_date: datetime
    r"""When the absence ends.The date that the absence ends. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    employee_note: Nullable[str]
    r"""A note describing the reason for this absence."""
    status: NotRequired[PostHrisAbsencesRequestBodyStatus]
    r"""The state that the absence should be created in. Some tools may approve absences automatically if they were created for an absence type that does not require approval."""
    start_half_day: NotRequired[bool]
    r"""`true` if the absence should start in the middle of the day."""
    end_half_day: NotRequired[bool]
    r"""`true` if the absence should end in the middle of the day."""
    amount: NotRequired[float]
    r"""The amount of time of the absence. Specifying this also requires specifying `unit`. This is supported by very few tools."""
    unit: NotRequired[PostHrisAbsencesRequestBodyUnit]
    r"""The time unit of the `amount` value. Specifying this also requires specifying `amount`."""
    start_time: NotRequired[str]
    r"""The time of when the absence begins. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `start_time` is specified, `end_time` has to be specified as well."""
    end_time: NotRequired[str]
    r"""The time of when the absence ends. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `end_time` is specified, `start_time` has to be specified as well."""
    remote_fields: NotRequired[PostHrisAbsencesRequestBodyRemoteFieldsTypedDict]
    r"""Additional fields that we will pass through to specific HRIS systems."""


class PostHrisAbsencesRequestBody(BaseModel):
    employee_id: str
    r"""The ID of the employee in Kombo or their ID in the remote system by prefixing it with `remote:` (e.g., `remote:12312`)"""

    absence_type_id: str
    r"""The ID of the absence type in Kombo (not its `remote_id`)."""

    start_date: datetime
    r"""The date that the absence starts. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    end_date: datetime
    r"""When the absence ends.The date that the absence ends. This is a plain date (i.e., `yyyy-MM-dd`), with all time information discarded.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    employee_note: Nullable[str]
    r"""A note describing the reason for this absence."""

    status: Optional[PostHrisAbsencesRequestBodyStatus] = "REQUESTED"
    r"""The state that the absence should be created in. Some tools may approve absences automatically if they were created for an absence type that does not require approval."""

    start_half_day: Optional[bool] = False
    r"""`true` if the absence should start in the middle of the day."""

    end_half_day: Optional[bool] = False
    r"""`true` if the absence should end in the middle of the day."""

    amount: Optional[float] = None
    r"""The amount of time of the absence. Specifying this also requires specifying `unit`. This is supported by very few tools."""

    unit: Optional[PostHrisAbsencesRequestBodyUnit] = None
    r"""The time unit of the `amount` value. Specifying this also requires specifying `amount`."""

    start_time: Optional[str] = None
    r"""The time of when the absence begins. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `start_time` is specified, `end_time` has to be specified as well."""

    end_time: Optional[str] = None
    r"""The time of when the absence ends. Follows the format `HH:mm` or `HH:mm:ss` (e.g., `14:45:15`). If `end_time` is specified, `start_time` has to be specified as well."""

    remote_fields: Optional[PostHrisAbsencesRequestBodyRemoteFields] = None
    r"""Additional fields that we will pass through to specific HRIS systems."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "status",
            "start_half_day",
            "end_half_day",
            "amount",
            "unit",
            "start_time",
            "end_time",
            "remote_fields",
        ]
        nullable_fields = ["employee_note"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


GetAtsCandidatesCandidateIDAttachmentsPositiveResponseType = Literal[
    "CV",
    "COVER_LETTER",
    "OTHER",
]


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResultTypedDict(TypedDict):
    id: str
    application_id: Nullable[str]
    r"""The Kombo ID of the application this attachment belongs to. When this is null, the attachment is not specific to any application but the candidate."""
    candidate_id: str
    r"""The Kombo ID of the candidate this attachment belongs to."""
    type: GetAtsCandidatesCandidateIDAttachmentsPositiveResponseType
    remote_id: str
    data_url: str
    file_name: str
    content_type: str
    r"""The MIME type of the attachment."""
    remote_created_at: Nullable[datetime]
    r"""The date when the attachment was created.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_updated_at: Nullable[datetime]
    r"""The date when the attachment was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResult(BaseModel):
    id: str

    application_id: Nullable[str]
    r"""The Kombo ID of the application this attachment belongs to. When this is null, the attachment is not specific to any application but the candidate."""

    candidate_id: str
    r"""The Kombo ID of the candidate this attachment belongs to."""

    type: GetAtsCandidatesCandidateIDAttachmentsPositiveResponseType

    remote_id: str

    data_url: str

    file_name: str

    content_type: str
    r"""The MIME type of the attachment."""

    remote_created_at: Nullable[datetime]
    r"""The date when the attachment was created.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_updated_at: Nullable[datetime]
    r"""The date when the attachment was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["application_id", "remote_created_at", "remote_updated_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict(TypedDict):
    results: List[GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResultTypedDict]


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponseData(BaseModel):
    results: List[GetAtsCandidatesCandidateIDAttachmentsPositiveResponseResult]


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict(TypedDict):
    message: str


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning(BaseModel):
    message: str


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponseTypedDict(TypedDict):
    data: GetAtsCandidatesCandidateIDAttachmentsPositiveResponseDataTypedDict
    warnings: List[
        GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarningTypedDict
    ]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class GetAtsCandidatesCandidateIDAttachmentsPositiveResponse(BaseModel):
    data: GetAtsCandidatesCandidateIDAttachmentsPositiveResponseData

    warnings: List[GetAtsCandidatesCandidateIDAttachmentsPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
    UnrecognizedStr,
)
from kombo.utils import validate_const, validate_open_enum
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator, PlainValidator
from typing import Any, Dict, List, Literal, Union
from typing_extensions import Annotated, NotRequired, TypedDict


GetHrisEmploymentsPositiveResponsePayPeriod = Union[
    Literal[
        "HOUR",
        "DAY",
        "WEEK",
        "TWO_WEEKS",
        "HALF_MONTH",
        "MONTH",
        "TWO_MONTHS",
        "QUARTER",
        "HALF_YEAR",
        "YEAR",
    ],
    UnrecognizedStr,
]


GetHrisEmploymentsPositiveResponsePayFrequency = Union[
    Literal[
        "DAILY",
        "WEEKLY",
        "BIWEEKLY",
        "MONTHLY",
        "SEMIMONTHLY",
        "QUARTERLY",
        "SEMIANNUALLY",
        "ANNUALLY",
        "PRO_RATA",
    ],
    UnrecognizedStr,
]


GetHrisEmploymentsPositiveResponseEmploymentType = Union[
    Literal[
        "FULL_TIME",
        "PART_TIME",
        "CONTRACT",
        "INTERNSHIP",
        "FREELANCE",
        "WORKING_STUDENT",
        "APPRENTICESHIP",
        "TRAINING",
    ],
    UnrecognizedStr,
]


class GetHrisEmploymentsPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    employee_id: str
    r"""The Kombo ID of the employment’s employee. The ID can be used to retrieve the employee from the `get employees` endpoint."""
    job_title: Nullable[str]
    r"""This field can contain historic job titles. Please use the `job_title` field on the employee for the active job title of an employee."""
    pay_rate: Nullable[float]
    r"""The monetary amount paid to an employee."""
    pay_currency: Nullable[str]
    r"""The currency that the employee is paid in. Usually returned in [ISO 4217 currency codes](https://www.iso.org/iso-4217-currency-codes.html)."""
    effective_date: Nullable[datetime]
    r"""The date of when the employment started.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""
    pay_period: NotRequired[Nullable[GetHrisEmploymentsPositiveResponsePayPeriod]]
    r"""The time interval which the `pay_rate` is describing.

    A `pay_rate` value of `12000` with a `pay_period` of `YEAR` would indicate that the employee receives 12000 over the course of a year. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    pay_frequency: NotRequired[Nullable[GetHrisEmploymentsPositiveResponsePayFrequency]]
    r"""The time interval at which the employee receives payment.

    A `pay_rate` of `12000`, with a `pay_period` of `YEAR`, and a `pay_frequency` of `MONTHLY` would indicate that the employee is paid 1000 every month. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """
    employment_type: NotRequired[
        Nullable[GetHrisEmploymentsPositiveResponseEmploymentType]
    ]
    r"""The employee’s current employment type:

    - `FULL_TIME`: the employee is actively employed
    - `PART_TIME`: the employee is working only part of the usual working hours
    - `CONTRACT`: the employee is working temporarily under a contract
    - `INTERNSHIP`: the employee is working as an intern
    - `FREELANCE`: the employee is working as a freelancer
    - `WORKING_STUDENT`: the employee is working as a working student
    - `APPRENTICESHIP`: the employee is working in an apprenticeship
    - `TRAINING`: the employee is working in a training program

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """


class GetHrisEmploymentsPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    employee_id: str
    r"""The Kombo ID of the employment’s employee. The ID can be used to retrieve the employee from the `get employees` endpoint."""

    job_title: Nullable[str]
    r"""This field can contain historic job titles. Please use the `job_title` field on the employee for the active job title of an employee."""

    pay_rate: Nullable[float]
    r"""The monetary amount paid to an employee."""

    pay_currency: Nullable[str]
    r"""The currency that the employee is paid in. Usually returned in [ISO 4217 currency codes](https://www.iso.org/iso-4217-currency-codes.html)."""

    effective_date: Nullable[datetime]
    r"""The date of when the employment started.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    custom_fields: Nullable[Dict[str, Any]]
    r"""A key-value store of fields not covered by the schema. [Read more](/custom-fields)"""

    pay_period: Annotated[
        OptionalNullable[GetHrisEmploymentsPositiveResponsePayPeriod],
        PlainValidator(validate_open_enum(False)),
    ] = UNSET
    r"""The time interval which the `pay_rate` is describing.

    A `pay_rate` value of `12000` with a `pay_period` of `YEAR` would indicate that the employee receives 12000 over the course of a year. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    pay_frequency: Annotated[
        OptionalNullable[GetHrisEmploymentsPositiveResponsePayFrequency],
        PlainValidator(validate_open_enum(False)),
    ] = UNSET
    r"""The time interval at which the employee receives payment.

    A `pay_rate` of `12000`, with a `pay_period` of `YEAR`, and a `pay_frequency` of `MONTHLY` would indicate that the employee is paid 1000 every month. In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    employment_type: Annotated[
        OptionalNullable[GetHrisEmploymentsPositiveResponseEmploymentType],
        PlainValidator(validate_open_enum(False)),
    ] = UNSET
    r"""The employee’s current employment type:

    - `FULL_TIME`: the employee is actively employed
    - `PART_TIME`: the employee is working only part of the usual working hours
    - `CONTRACT`: the employee is working temporarily under a contract
    - `INTERNSHIP`: the employee is working as an intern
    - `FREELANCE`: the employee is working as a freelancer
    - `WORKING_STUDENT`: the employee is working as a working student
    - `APPRENTICESHIP`: the employee is working in an apprenticeship
    - `TRAINING`: the employee is working in a training program

    In rare cases where we can’t find a clear mapping, the original string is passed through.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["pay_period", "pay_frequency", "employment_type"]
        nullable_fields = [
            "remote_id",
            "job_title",
            "pay_rate",
            "pay_period",
            "pay_frequency",
            "employment_type",
            "pay_currency",
            "effective_date",
            "remote_deleted_at",
            "custom_fields",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisEmploymentsPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetHrisEmploymentsPositiveResponseResultTypedDict]


class GetHrisEmploymentsPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetHrisEmploymentsPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisEmploymentsPositiveResponseTypedDict(TypedDict):
    data: GetHrisEmploymentsPositiveResponseDataTypedDict
    status: Literal["success"]


class GetHrisEmploymentsPositiveResponse(BaseModel):
    data: GetHrisEmploymentsPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal
from typing_extensions import TypedDict


IntegrationCreatedWebhookPayloadType = Literal["integration-created",]
r"""Type of the webhook event"""


IntegrationCreatedWebhookPayloadCategory = Literal[
    "HRIS",
    "ATS",
    "ASSESSMENT",
]
r"""The category of the integration."""


class IntegrationCreatedWebhookPayloadEndUserTypedDict(TypedDict):
    r"""Information about the end user who created the integration."""

    organization_name: str
    r"""The name of the organization that owns the integration."""
    creator_email: Nullable[str]
    r"""The email address of the user who created the integration."""
    origin_id: Nullable[str]
    r"""The unique identifier of the organization in the integrated system."""


class IntegrationCreatedWebhookPayloadEndUser(BaseModel):
    r"""Information about the end user who created the integration."""

    organization_name: str
    r"""The name of the organization that owns the integration."""

    creator_email: Nullable[str]
    r"""The email address of the user who created the integration."""

    origin_id: Nullable[str]
    r"""The unique identifier of the organization in the integrated system."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["creator_email", "origin_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class IntegrationCreatedWebhookPayloadDataTypedDict(TypedDict):
    id: str
    r"""The unique identifier of the newly created integration."""
    tool: str
    r"""The name of the integrated tool."""
    category: IntegrationCreatedWebhookPayloadCategory
    r"""The category of the integration."""
    end_user: IntegrationCreatedWebhookPayloadEndUserTypedDict
    r"""Information about the end user who created the integration."""


class IntegrationCreatedWebhookPayloadData(BaseModel):
    id: str
    r"""The unique identifier of the newly created integration."""

    tool: str
    r"""The name of the integrated tool."""

    category: IntegrationCreatedWebhookPayloadCategory
    r"""The category of the integration."""

    end_user: IntegrationCreatedWebhookPayloadEndUser
    r"""Information about the end user who created the integration."""


class IntegrationCreatedWebhookPayloadTypedDict(TypedDict):
    id: str
    r"""Unique identifier for this webhook event"""
    type: IntegrationCreatedWebhookPayloadType
    r"""Type of the webhook event"""
    data: IntegrationCreatedWebhookPayloadDataTypedDict


class IntegrationCreatedWebhookPayload(BaseModel):
    id: str
    r"""Unique identifier for this webhook event"""

    type: IntegrationCreatedWebhookPayloadType
    r"""Type of the webhook event"""

    data: IntegrationCreatedWebhookPayloadData



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, NotRequired, TypedDict


class GetAtsInterviewsPositiveResponseLocationTypedDict(TypedDict):
    r"""Location of the interview."""

    city: NotRequired[Nullable[str]]
    country: NotRequired[Nullable[str]]
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""
    raw: NotRequired[Nullable[str]]
    r"""If we have address data, this is filled with the raw address string."""
    state: NotRequired[Nullable[str]]
    street_1: NotRequired[Nullable[str]]
    r"""If we can parse the address data, this field contains the first part of the street information."""
    street_2: NotRequired[Nullable[str]]
    zip_code: NotRequired[Nullable[str]]


class GetAtsInterviewsPositiveResponseLocation(BaseModel):
    r"""Location of the interview."""

    city: OptionalNullable[str] = UNSET

    country: OptionalNullable[str] = UNSET
    r"""Contains the ISO2 country code if possible. If not, it contains the original value."""

    raw: OptionalNullable[str] = UNSET
    r"""If we have address data, this is filled with the raw address string."""

    state: OptionalNullable[str] = UNSET

    street_1: OptionalNullable[str] = UNSET
    r"""If we can parse the address data, this field contains the first part of the street information."""

    street_2: OptionalNullable[str] = UNSET

    zip_code: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "city",
            "country",
            "raw",
            "state",
            "street_1",
            "street_2",
            "zip_code",
        ]
        nullable_fields = [
            "city",
            "country",
            "raw",
            "state",
            "street_1",
            "street_2",
            "zip_code",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class UserTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    first_name: Nullable[str]
    r"""First name of the user."""
    last_name: Nullable[str]
    r"""Last name of the user."""
    email: NotRequired[Nullable[str]]
    r"""Email of the user. If the email address is invalid, it will be set to null."""


class User(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    first_name: Nullable[str]
    r"""First name of the user."""

    last_name: Nullable[str]
    r"""Last name of the user."""

    email: OptionalNullable[str] = UNSET
    r"""Email of the user. If the email address is invalid, it will be set to null."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["email"]
        nullable_fields = ["remote_id", "first_name", "last_name", "email"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


GetAtsInterviewsPositiveResponseOutcome = Literal[
    "PENDING",
    "HIRED",
    "DECLINED",
]
r"""Parsed status of the application. If Kombo identifies that the application was accepted and the candidate hired, it will be `HIRED`. If the application was rejected or the candidate declined, it will be `DECLINED`. If the application is still in process, it will be `PENDING`.
Kombo will always try to deliver this information as reliably as possible.
"""


class GetAtsInterviewsPositiveResponseEmailAddressTypedDict(TypedDict):
    type: Nullable[str]
    r"""Kombo exposes type information through this field. If we don't get any information from the tool, we will set this to `null`."""
    email_address: NotRequired[Nullable[str]]


class GetAtsInterviewsPositiveResponseEmailAddress(BaseModel):
    type: Nullable[str]
    r"""Kombo exposes type information through this field. If we don't get any information from the tool, we will set this to `null`."""

    email_address: OptionalNullable[str] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["email_address"]
        nullable_fields = ["email_address", "type"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAtsInterviewsPositiveResponseCandidateTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    first_name: Nullable[str]
    r"""First name of the candidate."""
    last_name: Nullable[str]
    r"""Last name of the candidate."""
    email_addresses: NotRequired[
        Nullable[List[GetAtsInterviewsPositiveResponseEmailAddressTypedDict]]
    ]
    r"""A list of email addresses of the candidate with an optional type. If an email address is invalid, it will be filtered out."""


class GetAtsInterviewsPositiveResponseCandidate(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    first_name: Nullable[str]
    r"""First name of the candidate."""

    last_name: Nullable[str]
    r"""Last name of the candidate."""

    email_addresses: OptionalNullable[
        List[GetAtsInterviewsPositiveResponseEmailAddress]
    ] = UNSET
    r"""A list of email addresses of the candidate with an optional type. If an email address is invalid, it will be filtered out."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["email_addresses"]
        nullable_fields = ["first_name", "last_name", "email_addresses"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAtsInterviewsPositiveResponseJobTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""Title of the job."""


class GetAtsInterviewsPositiveResponseJob(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""Title of the job."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["name"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAtsInterviewsPositiveResponseApplicationTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    outcome: Nullable[GetAtsInterviewsPositiveResponseOutcome]
    r"""Parsed status of the application. If Kombo identifies that the application was accepted and the candidate hired, it will be `HIRED`. If the application was rejected or the candidate declined, it will be `DECLINED`. If the application is still in process, it will be `PENDING`.
    Kombo will always try to deliver this information as reliably as possible.
    """
    rejection_reason_name: Nullable[str]
    r"""Reason for the rejection of the candidate."""
    candidate: Nullable[GetAtsInterviewsPositiveResponseCandidateTypedDict]
    job: Nullable[GetAtsInterviewsPositiveResponseJobTypedDict]


class GetAtsInterviewsPositiveResponseApplication(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    outcome: Nullable[GetAtsInterviewsPositiveResponseOutcome]
    r"""Parsed status of the application. If Kombo identifies that the application was accepted and the candidate hired, it will be `HIRED`. If the application was rejected or the candidate declined, it will be `DECLINED`. If the application is still in process, it will be `PENDING`.
    Kombo will always try to deliver this information as reliably as possible.
    """

    rejection_reason_name: Nullable[str]
    r"""Reason for the rejection of the candidate."""

    candidate: Nullable[GetAtsInterviewsPositiveResponseCandidate]

    job: Nullable[GetAtsInterviewsPositiveResponseJob]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = [
            "remote_id",
            "outcome",
            "rejection_reason_name",
            "candidate",
            "job",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAtsInterviewsPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    title: Nullable[str]
    r"""The title of the interview."""
    starting_at: Nullable[datetime]
    r"""The start time of the interview.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    ending_at: Nullable[datetime]
    r"""The end time of the interview.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    application_id: Nullable[str]
    r"""The Kombo ID of the application this interview belongs to. The ID can be used to retrieve the application from the `get applications` endpoint."""
    stage_id: Nullable[str]
    r"""If a system specifies to which stage this interview belongs to, this field will be the Kombo ID of the application stage. The ID can be used to retrieve the stage from the `get application stages` endpoint."""
    canceled: Nullable[bool]
    r"""Whether the interview was canceled or not. If we have no information, this field will be `null`."""
    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_updated_at: Nullable[datetime]
    r"""A timestamp retrieved from the remote system, describing when the resource was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    users: List[UserTypedDict]
    application: Nullable[GetAtsInterviewsPositiveResponseApplicationTypedDict]
    location: NotRequired[Nullable[GetAtsInterviewsPositiveResponseLocationTypedDict]]
    r"""Location of the interview."""


class GetAtsInterviewsPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: Nullable[str]
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    title: Nullable[str]
    r"""The title of the interview."""

    starting_at: Nullable[datetime]
    r"""The start time of the interview.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    ending_at: Nullable[datetime]
    r"""The end time of the interview.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    application_id: Nullable[str]
    r"""The Kombo ID of the application this interview belongs to. The ID can be used to retrieve the application from the `get applications` endpoint."""

    stage_id: Nullable[str]
    r"""If a system specifies to which stage this interview belongs to, this field will be the Kombo ID of the application stage. The ID can be used to retrieve the stage from the `get application stages` endpoint."""

    canceled: Nullable[bool]
    r"""Whether the interview was canceled or not. If we have no information, this field will be `null`."""

    remote_created_at: Nullable[datetime]
    r"""The date and time the object was created in the remote system.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_updated_at: Nullable[datetime]
    r"""A timestamp retrieved from the remote system, describing when the resource was last updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    users: List[User]

    application: Nullable[GetAtsInterviewsPositiveResponseApplication]

    location: OptionalNullable[GetAtsInterviewsPositiveResponseLocation] = UNSET
    r"""Location of the interview."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["location"]
        nullable_fields = [
            "remote_id",
            "title",
            "starting_at",
            "ending_at",
            "location",
            "application_id",
            "stage_id",
            "canceled",
            "remote_created_at",
            "remote_updated_at",
            "remote_deleted_at",
            "application",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAtsInterviewsPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetAtsInterviewsPositiveResponseResultTypedDict]


class GetAtsInterviewsPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetAtsInterviewsPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetAtsInterviewsPositiveResponseTypedDict(TypedDict):
    data: GetAtsInterviewsPositiveResponseDataTypedDict
    status: Literal["success"]


class GetAtsInterviewsPositiveResponse(BaseModel):
    data: GetAtsInterviewsPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


class GetIntegrationsIntegrationIDPositiveResponseToolTypedDict(TypedDict):
    id: str
    r"""The ID of the connected tool in Kombo (e.g. `factorial`)."""
    label: str
    internal_label: Nullable[str]
    r"""Internal label that can help you debug specific variants of the integration. Only show the `label` to your users."""
    logo_url: str
    r"""URL to an SVG logo of the connected tool. The logo usually contains the tool name."""
    icon_url: str
    r"""URL to a square SVG icon of the connected tool."""


class GetIntegrationsIntegrationIDPositiveResponseTool(BaseModel):
    id: str
    r"""The ID of the connected tool in Kombo (e.g. `factorial`)."""

    label: str

    internal_label: Nullable[str]
    r"""Internal label that can help you debug specific variants of the integration. Only show the `label` to your users."""

    logo_url: str
    r"""URL to an SVG logo of the connected tool. The logo usually contains the tool name."""

    icon_url: str
    r"""URL to a square SVG icon of the connected tool."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["internal_label"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


GetIntegrationsIntegrationIDPositiveResponseCategory = Literal[
    "HRIS",
    "ATS",
    "ASSESSMENT",
]


GetIntegrationsIntegrationIDPositiveResponseStatus = Literal[
    "ACTIVE",
    "INVALID",
    "INACTIVE",
]
r"""The current status of the integration.

- `ACTIVE`: The integration is syncing data as expected.
- `INVALID`: The integration has stopped syncing data because of invalid credentials. To fix this, reach out to your customer to [reconnect the integration](../guides/integration-states#credentials-invalid).
- `INACTIVE`: The integration has stopped syncing as it's been manually set to inactive. You can [enable it again](../guides/integration-states#inactive) in the integration's page.
"""


GetIntegrationsIntegrationIDPositiveResponseSetupStatus = Literal[
    "INCOMPLETE",
    "FINAL_SYNC_PENDING",
    "COMPLETED",
]
r"""The setup_status is used in conjunction with the filtering and field mapping features. If these are enabled in the connection flow, the integration will start in an \"INCOMPLETE\" state and move to \"COMPLETE\" once all steps are finished.

- `INCOMPLETE`: Setup is still in progress. Some steps aren’t finished, so no data is available yet. Syncs only run as needed for setup.
- `FINAL_SYNC_PENDING`: Setup is complete, and the final sync is running. Data will be available after this sync is done.
- `COMPLETED`: Setup is fully finished, and the integration is ready to use.
"""


class GetIntegrationsIntegrationIDPositiveResponseEndUserTypedDict(TypedDict):
    organization_name: str
    creator_email: Nullable[str]
    origin_id: Nullable[str]
    r"""The ID you have passed initially to the connection flow to create this integration."""


class GetIntegrationsIntegrationIDPositiveResponseEndUser(BaseModel):
    organization_name: str

    creator_email: Nullable[str]

    origin_id: Nullable[str]
    r"""The ID you have passed initially to the connection flow to create this integration."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["creator_email", "origin_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ScopeConfigTypedDict(TypedDict):
    id: str
    name: Nullable[str]


class ScopeConfig(BaseModel):
    id: str

    name: Nullable[str]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["name"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


GetIntegrationsIntegrationIDPositiveResponseCoverageStatus = Literal[
    "SUPPORTED",
    "UNSUPPORTED",
    "NOT_IMPLEMENTED",
    "UNKNOWN",
]
r"""The status of a datapoint of an integrated tool:

- `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
- `UNSUPPORTED`: the tool does not support the datapoint.
- `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
- `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
"""


ScopeConfigSetting = Literal[
    "ENABLED",
    "DISABLED",
    "OPTIONAL",
]
r"""The setting of the datapoint in the scope config that you configured in the Kombo dashboard."""


GetIntegrationsIntegrationIDPositiveResponseFieldCoverageStatus = Literal[
    "SUPPORTED",
    "UNSUPPORTED",
    "NOT_IMPLEMENTED",
    "UNKNOWN",
]
r"""The status of a datapoint of an integrated tool:

- `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
- `UNSUPPORTED`: the tool does not support the datapoint.
- `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
- `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
"""


FieldScopeConfigSetting = Literal[
    "ENABLED",
    "DISABLED",
    "OPTIONAL",
]
r"""The setting of the datapoint in the scope config that you configured in the Kombo dashboard."""


class GetIntegrationsIntegrationIDPositiveResponseFieldTypedDict(TypedDict):
    id: str
    r"""Key of the field in the API (e.g. first_name)."""
    is_available: bool
    r"""Whether the datapoint is available and enabled and not opted out of."""
    coverage_status: GetIntegrationsIntegrationIDPositiveResponseFieldCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """
    scope_config_setting: FieldScopeConfigSetting
    r"""The setting of the datapoint in the scope config that you configured in the Kombo dashboard."""
    opted_out_by_customer: bool
    r"""Whether the datapoint is opted out by your customer in the connection flow."""


class GetIntegrationsIntegrationIDPositiveResponseField(BaseModel):
    id: str
    r"""Key of the field in the API (e.g. first_name)."""

    is_available: bool
    r"""Whether the datapoint is available and enabled and not opted out of."""

    coverage_status: GetIntegrationsIntegrationIDPositiveResponseFieldCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """

    scope_config_setting: FieldScopeConfigSetting
    r"""The setting of the datapoint in the scope config that you configured in the Kombo dashboard."""

    opted_out_by_customer: bool
    r"""Whether the datapoint is opted out by your customer in the connection flow."""


class GetIntegrationsIntegrationIDPositiveResponseReadModelTypedDict(TypedDict):
    id: str
    r"""ID of the model (e.g. hris_employees)."""
    label: str
    r"""Label of the model (e.g. Employees)."""
    is_available: bool
    r"""Whether the datapoint is available and enabled and not opted out of."""
    coverage_status: GetIntegrationsIntegrationIDPositiveResponseCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """
    scope_config_setting: ScopeConfigSetting
    r"""The setting of the datapoint in the scope config that you configured in the Kombo dashboard."""
    opted_out_by_customer: bool
    r"""Whether the datapoint is opted out by your customer in the connection flow."""
    fields: List[GetIntegrationsIntegrationIDPositiveResponseFieldTypedDict]


class GetIntegrationsIntegrationIDPositiveResponseReadModel(BaseModel):
    id: str
    r"""ID of the model (e.g. hris_employees)."""

    label: str
    r"""Label of the model (e.g. Employees)."""

    is_available: bool
    r"""Whether the datapoint is available and enabled and not opted out of."""

    coverage_status: GetIntegrationsIntegrationIDPositiveResponseCoverageStatus
    r"""The status of a datapoint of an integrated tool:

    - `SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.
    - `UNSUPPORTED`: the tool does not support the datapoint.
    - `NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).
    - `UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it's availability in the tool.
    """

    scope_config_setting: ScopeConfigSetting
    r"""The setting of the datapoint in the scope config that you configured in the Kombo dashboard."""

    opted_out_by_customer: bool
    r"""Whether the datapoint is opted out by your customer in the connection flow."""

    fields: List[GetIntegrationsIntegrationIDPositiveResponseField]


class GetIntegrationsIntegrationIDPositiveResponseDataTypedDict(TypedDict):
    id: str
    tool: GetIntegrationsIntegrationIDPositiveResponseToolTypedDict
    category: GetIntegrationsIntegrationIDPositiveResponseCategory
    status: GetIntegrationsIntegrationIDPositiveResponseStatus
    r"""The current status of the integration.

    - `ACTIVE`: The integration is syncing data as expected.
    - `INVALID`: The integration has stopped syncing data because of invalid credentials. To fix this, reach out to your customer to [reconnect the integration](../guides/integration-states#credentials-invalid).
    - `INACTIVE`: The integration has stopped syncing as it's been manually set to inactive. You can [enable it again](../guides/integration-states#inactive) in the integration's page.
    """
    setup_status: GetIntegrationsIntegrationIDPositiveResponseSetupStatus
    r"""The setup_status is used in conjunction with the filtering and field mapping features. If these are enabled in the connection flow, the integration will start in an \"INCOMPLETE\" state and move to \"COMPLETE\" once all steps are finished.

    - `INCOMPLETE`: Setup is still in progress. Some steps aren’t finished, so no data is available yet. Syncs only run as needed for setup.
    - `FINAL_SYNC_PENDING`: Setup is complete, and the final sync is running. Data will be available after this sync is done.
    - `COMPLETED`: Setup is fully finished, and the integration is ready to use.
    """
    end_user: GetIntegrationsIntegrationIDPositiveResponseEndUserTypedDict
    scope_config: ScopeConfigTypedDict
    created_at: datetime
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    beta: bool
    read_models: List[GetIntegrationsIntegrationIDPositiveResponseReadModelTypedDict]


class GetIntegrationsIntegrationIDPositiveResponseData(BaseModel):
    id: str

    tool: GetIntegrationsIntegrationIDPositiveResponseTool

    category: GetIntegrationsIntegrationIDPositiveResponseCategory

    status: GetIntegrationsIntegrationIDPositiveResponseStatus
    r"""The current status of the integration.

    - `ACTIVE`: The integration is syncing data as expected.
    - `INVALID`: The integration has stopped syncing data because of invalid credentials. To fix this, reach out to your customer to [reconnect the integration](../guides/integration-states#credentials-invalid).
    - `INACTIVE`: The integration has stopped syncing as it's been manually set to inactive. You can [enable it again](../guides/integration-states#inactive) in the integration's page.
    """

    setup_status: GetIntegrationsIntegrationIDPositiveResponseSetupStatus
    r"""The setup_status is used in conjunction with the filtering and field mapping features. If these are enabled in the connection flow, the integration will start in an \"INCOMPLETE\" state and move to \"COMPLETE\" once all steps are finished.

    - `INCOMPLETE`: Setup is still in progress. Some steps aren’t finished, so no data is available yet. Syncs only run as needed for setup.
    - `FINAL_SYNC_PENDING`: Setup is complete, and the final sync is running. Data will be available after this sync is done.
    - `COMPLETED`: Setup is fully finished, and the integration is ready to use.
    """

    end_user: GetIntegrationsIntegrationIDPositiveResponseEndUser

    scope_config: ScopeConfig

    created_at: datetime
    r"""YYYY-MM-DDTHH:mm:ss.sssZ
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    beta: bool

    read_models: List[GetIntegrationsIntegrationIDPositiveResponseReadModel]


class GetIntegrationsIntegrationIDPositiveResponseTypedDict(TypedDict):
    data: GetIntegrationsIntegrationIDPositiveResponseDataTypedDict
    status: Literal["success"]


class GetIntegrationsIntegrationIDPositiveResponse(BaseModel):
    data: GetIntegrationsIntegrationIDPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


PostForceSyncRequestBodyType = Literal[
    "FULL",
    "DELTA",
]
r"""The type of the triggered sync."""


class PostForceSyncRequestBodyTypedDict(TypedDict):
    type: NotRequired[PostForceSyncRequestBodyType]
    r"""The type of the triggered sync."""


class PostForceSyncRequestBody(BaseModel):
    type: Optional[PostForceSyncRequestBodyType] = "FULL"
    r"""The type of the triggered sync."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal
from typing_extensions import Annotated, TypedDict


GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseType = Literal[
    "DEFAULT",
    "CUSTOM",
]
r"""The type of the integration field. There is a type to avoid collisions between DEFAULT fields and CUSTOM fields with the same key."""


class GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResultTypedDict(
    TypedDict
):
    id: str
    r"""The unique ID of the field."""
    key: str
    r"""The key of the field in the remote system."""
    model: str
    r"""The model the field is associated with."""
    type: GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseType
    r"""The type of the integration field. There is a type to avoid collisions between DEFAULT fields and CUSTOM fields with the same key."""
    label: Nullable[str]
    r"""The label of the field in the remote system."""
    is_passthrough_enabled: bool
    r"""Whether the field is included in the integrations_fields array of the corresponding model."""
    is_writable: Literal[False]
    r"""This field is related to a deprecated feature and means nothing, but is kept for backwards compatibility."""


class GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResult(BaseModel):
    id: str
    r"""The unique ID of the field."""

    key: str
    r"""The key of the field in the remote system."""

    model: str
    r"""The model the field is associated with."""

    type: GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseType
    r"""The type of the integration field. There is a type to avoid collisions between DEFAULT fields and CUSTOM fields with the same key."""

    label: Nullable[str]
    r"""The label of the field in the remote system."""

    is_passthrough_enabled: bool
    r"""Whether the field is included in the integrations_fields array of the corresponding model."""

    IS_WRITABLE: Annotated[
        Annotated[Literal[False], AfterValidator(validate_const(False))],
        pydantic.Field(alias="is_writable"),
    ] = False
    r"""This field is related to a deprecated feature and means nothing, but is kept for backwards compatibility."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["label"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseDataTypedDict(
    TypedDict
):
    results: List[
        GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResultTypedDict
    ]
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""


class GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseData(BaseModel):
    results: List[GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseResult]

    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseTypedDict(TypedDict):
    data: GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseDataTypedDict
    status: Literal["success"]


class GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponse(BaseModel):
    data: GetIntegrationsIntegrationIDIntegrationFieldsPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from kombo.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


GetHrisPerformanceReviewsPositiveResponseType = Literal[
    "MANAGER",
    "DIRECT_REPORT",
    "PEER",
    "SELF",
]
r"""The relationship between the reviewee and reviewer. Manager: The reviewer is the manager of the reviewee. Direct Report: The reviewer is a direct report of the reviewee (reverse MANAGER). Peer: The reviewer is a peer of the reviewee. Self: The reviewer is the reviewee himself/herself. null: The relationship cannot be determined or the reviewer is missing."""


class SummaryRatingSingleSelectTypedDict(TypedDict):
    ordered_options: Nullable[List[str]]
    r"""The options of the summary rating. Ordered from bad to good."""
    value: Nullable[str]
    r"""The text value of the summary rating."""
    type: Literal["SINGLE_SELECT"]


class SummaryRatingSingleSelect(BaseModel):
    ordered_options: Nullable[List[str]]
    r"""The options of the summary rating. Ordered from bad to good."""

    value: Nullable[str]
    r"""The text value of the summary rating."""

    TYPE: Annotated[
        Annotated[
            Literal["SINGLE_SELECT"], AfterValidator(validate_const("SINGLE_SELECT"))
        ],
        pydantic.Field(alias="type"),
    ] = "SINGLE_SELECT"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["ordered_options", "value"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class SummaryRatingNumericTypedDict(TypedDict):
    min: Nullable[float]
    r"""The minimum value of the summary rating."""
    max: Nullable[float]
    r"""The maximum value of the summary rating."""
    value: Nullable[float]
    r"""The numeric value of the summary rating."""
    type: Literal["NUMERIC"]


class SummaryRatingNumeric(BaseModel):
    min: Nullable[float]
    r"""The minimum value of the summary rating."""

    max: Nullable[float]
    r"""The maximum value of the summary rating."""

    value: Nullable[float]
    r"""The numeric value of the summary rating."""

    TYPE: Annotated[
        Annotated[Literal["NUMERIC"], AfterValidator(validate_const("NUMERIC"))],
        pydantic.Field(alias="type"),
    ] = "NUMERIC"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["min", "max", "value"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


SummaryRatingTypedDict = TypeAliasType(
    "SummaryRatingTypedDict",
    Union[SummaryRatingSingleSelectTypedDict, SummaryRatingNumericTypedDict],
)
r"""The summary rating of the performance review."""


SummaryRating = TypeAliasType(
    "SummaryRating", Union[SummaryRatingSingleSelect, SummaryRatingNumeric]
)
r"""The summary rating of the performance review."""


class RevieweeTypedDict(TypedDict):
    r"""The employee receiving the review."""

    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    first_name: Nullable[str]
    r"""The employee’s first name."""
    last_name: Nullable[str]
    r"""The employee’s last name."""
    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    work_email: NotRequired[Nullable[str]]
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""


class Reviewee(BaseModel):
    r"""The employee receiving the review."""

    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    first_name: Nullable[str]
    r"""The employee’s first name."""

    last_name: Nullable[str]
    r"""The employee’s last name."""

    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    work_email: OptionalNullable[str] = UNSET
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["work_email"]
        nullable_fields = [
            "first_name",
            "last_name",
            "display_full_name",
            "work_email",
            "remote_deleted_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ReviewerTypedDict(TypedDict):
    r"""The employee giving/writing the review."""

    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    first_name: Nullable[str]
    r"""The employee’s first name."""
    last_name: Nullable[str]
    r"""The employee’s last name."""
    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    work_email: NotRequired[Nullable[str]]
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""


class Reviewer(BaseModel):
    r"""The employee giving/writing the review."""

    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    first_name: Nullable[str]
    r"""The employee’s first name."""

    last_name: Nullable[str]
    r"""The employee’s last name."""

    display_full_name: Nullable[str]
    r"""The employee’s full name, including any middle names. Not all HR systems provide an explicit display name, so we recommend falling back to `first_name` and `last_name`."""

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    work_email: OptionalNullable[str] = UNSET
    r"""The employee’s work email address. If the email address is invalid, we will set this to `null`."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["work_email"]
        nullable_fields = [
            "first_name",
            "last_name",
            "display_full_name",
            "work_email",
            "remote_deleted_at",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class ReviewCycleTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    name: Nullable[str]
    r"""The name of the performance review cycle."""
    review_period_start_date: Nullable[datetime]
    r"""The start date of the review period of the performance review cycle. It is the start date of the evaluation timeframe and the earliest date reviews can be submitted for this cycle.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """


class ReviewCycle(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    name: Nullable[str]
    r"""The name of the performance review cycle."""

    review_period_start_date: Nullable[datetime]
    r"""The start date of the review period of the performance review cycle. It is the start date of the evaluation timeframe and the earliest date reviews can be submitted for this cycle.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["name", "review_period_start_date", "remote_deleted_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisPerformanceReviewsPositiveResponseResultTypedDict(TypedDict):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""
    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""
    type: Nullable[GetHrisPerformanceReviewsPositiveResponseType]
    r"""The relationship between the reviewee and reviewer. Manager: The reviewer is the manager of the reviewee. Direct Report: The reviewer is a direct report of the reviewee (reverse MANAGER). Peer: The reviewer is a peer of the reviewee. Self: The reviewer is the reviewee himself/herself. null: The relationship cannot be determined or the reviewer is missing."""
    summary_comment: Nullable[str]
    r"""The summary comment of the performance review."""
    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """
    reviewee: RevieweeTypedDict
    r"""The employee receiving the review."""
    reviewer: Nullable[ReviewerTypedDict]
    r"""The employee giving/writing the review."""
    review_cycle: Nullable[ReviewCycleTypedDict]
    summary_rating: NotRequired[Nullable[SummaryRatingTypedDict]]
    r"""The summary rating of the performance review."""


class GetHrisPerformanceReviewsPositiveResponseResult(BaseModel):
    id: str
    r"""The globally unique ID of this object generated by Kombo. We recommend using this as a stable primary key for syncing."""

    remote_id: str
    r"""The raw ID of the object in the remote system. We don't recommend using this as a primary key on your side as it might sometimes be compromised of multiple identifiers if a system doesn't provide a clear primary key."""

    type: Nullable[GetHrisPerformanceReviewsPositiveResponseType]
    r"""The relationship between the reviewee and reviewer. Manager: The reviewer is the manager of the reviewee. Direct Report: The reviewer is a direct report of the reviewee (reverse MANAGER). Peer: The reviewer is a peer of the reviewee. Self: The reviewer is the reviewee himself/herself. null: The relationship cannot be determined or the reviewer is missing."""

    summary_comment: Nullable[str]
    r"""The summary comment of the performance review."""

    changed_at: datetime
    r"""The timestamp when this specific record was last modified. This field only updates when properties directly on this record change, NOT when related or nested models change. For filtering that considers nested data changes, use the `updated_after` parameter which will return records when either the record itself OR its related models have been updated.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    remote_deleted_at: Nullable[datetime]
    r"""The date and time the object was deleted in the remote system. Objects are automatically marked as deleted when Kombo can't retrieve them from the remote system anymore. Kombo will also anonymize entries 14 days after they disappear.
    https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date/toISOString
    """

    reviewee: Reviewee
    r"""The employee receiving the review."""

    reviewer: Nullable[Reviewer]
    r"""The employee giving/writing the review."""

    review_cycle: Nullable[ReviewCycle]

    summary_rating: OptionalNullable[SummaryRating] = UNSET
    r"""The summary rating of the performance review."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["summary_rating"]
        nullable_fields = [
            "type",
            "summary_comment",
            "summary_rating",
            "remote_deleted_at",
            "reviewer",
            "review_cycle",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisPerformanceReviewsPositiveResponseDataTypedDict(TypedDict):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""
    results: List[GetHrisPerformanceReviewsPositiveResponseResultTypedDict]


class GetHrisPerformanceReviewsPositiveResponseData(BaseModel):
    next: Nullable[str]
    r"""Cursor string that can be passed to the `cursor` query parameter to get the next page. If this is `null`, then there are no more pages."""

    results: List[GetHrisPerformanceReviewsPositiveResponseResult]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class GetHrisPerformanceReviewsPositiveResponseTypedDict(TypedDict):
    data: GetHrisPerformanceReviewsPositiveResponseDataTypedDict
    status: Literal["success"]


class GetHrisPerformanceReviewsPositiveResponse(BaseModel):
    data: GetHrisPerformanceReviewsPositiveResponseData

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"
